(_proxy_py_glossary)=
# {{ project }} Glossary

```{spelling}
DNS
DoH
Py
```

```{glossary}
DoH
DNS over HTTP
DNS-over-HTTP

  [DNS over HTTP]
```

```{glossary}
DNS

  Domain Name System
```

[DNS over HTTP]:
https://datatracker.ietf.org/doc/html/draft-pauly-dprive-oblivious-doh-04.html
